@@ -175,8 +175,11 @@ if(isset($_GET['action'])) {
 		if($dev_disable==0 && $sim_rs['dev_disable']==1) 
 			$db->query("update sim SET no_ring_remain=0,no_answer_remain=0,short_call_remain=0 where sim_name='$sim_name' and ((short_call_disable=1 and short_call_limit>0 and short_call_remain>=short_call_limit) or (no_ring_disable=1 and no_ring_limit>0 and no_ring_remain>=no_ring_limit) or (no_answer_disable=1 and no_answer_limit>0 and no_answer_remain>=no_answer_limit))");
 		$db->query("UPDATE sim SET imei_mode='$imei_mode', sim_team_id='$team_id',dev_disable='$dev_disable',plan_line_name='$_POST[line_name]',imei='$imei',time_limit='$_POST[time_limit]',time_unit='$time_unit',no_ring_limit='$_POST[no_ring_limit]',no_answer_limit='$_POST[no_answer_limit]',short_call_limit='$_POST[short_call_limit]',short_time='$_POST[short_time]',no_ring_disable='$_POST[no_ring_disable]',no_answer_disable='$_POST[no_answer_disable]',short_call_disable='$_POST[short_call_disable]',count_limit='$_POST[count_limit]',no_connected_limit='$_POST[no_connected_limit]',auto_reset_remain='$auto_reset_remain',auto_reset_remain_s='$auto_reset_remain_s',count_limit_no_connect='$_POST[count_limit_no_connect]',limit_sms='$_POST[limit_sms]',month_limit_time='$_POST[month_limit_time]',month_reset_day='$_POST[month_reset_day]' $t_remain WHERE sim_name='$sim_name'");
-
-
+		
+		if($dev_disable!=$sim_rs['dev_disable']){
+			if($dev_disable==0) $db->query("insert into logs set sim_name='$sim_name', log='enabled manually by single sim'");
+			else $db->query("insert into logs set sim_name='$sim_name', log='disabled manually by single sim'");
+		};
 		$query=$db->query("select sim.*,password from sim left join sim_bank on sim.bank_name=sim_bank.name where sim_name='$sim_name'");
 		while($row=$db->fetch_array($query)) {
 			sim_info($row, $send);
@@ -274,6 +277,13 @@ if(isset($_GET['action'])) {
 			$sql.="sim_login=sim_login $where";
 			if($_POST['dev_disable_modify'] && $dev_disable==0) 
 				$db->query("update sim SET no_ring_remain=0,no_answer_remain=0,short_call_remain=0 $where and dev_disable=1 and ((short_call_disable=1 and short_call_limit>0 and short_call_remain>=short_call_limit) or (no_ring_disable=1 and no_ring_limit>0 and no_ring_remain>=no_ring_limit) or (no_answer_disable=1 and no_answer_limit>0 and no_answer_remain>=no_answer_limit))");
+			if($_POST['dev_disable_modify']){
+				$query=$db->query("select sim_name from sim $where and dev_disable!='$dev_disable'");
+				while($row=$db->fetch_array($query)) {
+					if($dev_disable==0) $db->query("insert into logs set sim_name='$row[sim_name]', log='enabled batch manually'");
+					else $db->query("insert into logs set sim_name='$row[sim_name]', log='disabled batch manually'");
+				}
+			};
 
 			$db->query($sql);
 
