@@ -168,11 +168,18 @@ if(isset($_GET['action'])) {
 		if($sim_rs['time_limit']!=$_POST['time_limit']) $t_remain.=",remain_time=$_POST[time_limit]";
 		if($sim_rs['count_limit']!=$_POST['count_limit']) $t_remain.=",count_remain=$_POST[count_limit]";
 		if($sim_rs['limit_sms']!=$_POST['limit_sms']) $t_remain.=",remain_sms=$_POST[limit_sms]";
-		if($sim_rs['month_limit_time']!=$_POST['month_limit_time']) $t_remain.=",month_remain_time=$_POST[month_limit_time]";
+		if($sim_rs['month_limit_time']!=$_POST['month_limit_time']) {
+			$db->query("insert into logs set sim_name='$sim_name', log='change month limit'");
+			$t_remain.=",month_remain_time=$_POST[month_limit_time],month_last_reset_time=now()";
+		}
 		if($sim_rs['no_connected_limit']!=$_POST['no_connected_limit']) $t_remain.=",no_connected_remain=$_POST[no_connected_limit]";
 		if($dev_disable==0 && $sim_rs['dev_disable']==1) $t_remain.",no_ring_remain==if(),no_answer_remain=0,short_call_remain=0";
 		if($dev_disable==0 && $sim_rs['dev_disable']==1) 
 			$db->query("update sim SET no_ring_remain=0,no_answer_remain=0,short_call_remain=0 where sim_name='$sim_name' and ((short_call_disable=1 and short_call_limit>0 and short_call_remain>=short_call_limit) or (no_ring_disable=1 and no_ring_limit>0 and no_ring_remain>=no_ring_limit) or (no_answer_disable=1 and no_answer_limit>0 and no_answer_remain>=no_answer_limit))");
+		if($dev_disable!=$sim_rs['dev_disable']){
+			if($dev_disable==0) $db->query("insert into logs set sim_name='$sim_name', log='enabled manually by single sim'");
+			else $db->query("insert into logs set sim_name='$sim_name', log='disabled manually by single sim'");
+		};
 
 		$db->query("UPDATE sim SET imei_mode='$imei_mode', sim_team_id='$team_id',dev_disable='$dev_disable',plan_line_name='$_POST[line_name]',imei='$imei',time_limit='$_POST[time_limit]',time_unit='$time_unit',no_ring_limit='$_POST[no_ring_limit]',no_answer_limit='$_POST[no_answer_limit]',short_call_limit='$_POST[short_call_limit]',short_time='$_POST[short_time]',no_ring_disable='$_POST[no_ring_disable]',no_answer_disable='$_POST[no_answer_disable]',short_call_disable='$_POST[short_call_disable]',count_limit='$_POST[count_limit]',no_connected_limit='$_POST[no_connected_limit]',auto_reset_remain='$auto_reset_remain',auto_reset_remain_s='$auto_reset_remain_s',count_limit_no_connect='$_POST[count_limit_no_connect]',limit_sms='$_POST[limit_sms]',month_limit_time='$_POST[month_limit_time]',month_reset_day='$_POST[month_reset_day]' $t_remain WHERE sim_name='$sim_name'");
 
@@ -258,7 +265,7 @@ if(isset($_GET['action'])) {
 			$sql="UPDATE sim SET ";
 			if($_POST['team_id_modify']) $sql.="sim_team_id='$team_id',";
 			if($_POST['imei_mode_modify']) $sql.="imei_mode='$imei_mode',";
-			if($_POST['month_limit_time_modify']) $sql.="month_limit_time='$_POST[month_limit_time]',month_remain_time='$_POST[month_limit_time]',";
+			if($_POST['month_limit_time_modify']) $sql.="month_limit_time='$_POST[month_limit_time]',month_remain_time='$_POST[month_limit_time]',month_last_reset_time=now(),";
 			if($_POST['month_reset_day_modify']) $sql.="month_reset_day='$_POST[month_reset_day]',";
 			if($_POST['time_limit_modify']) $sql.="time_limit='$_POST[time_limit]',remain_time='$_POST[time_limit]',";
 			if($_POST['count_limit_modify']) $sql.="count_limit='$_POST[count_limit]',count_remain=$_POST[count_limit],";
@@ -276,12 +283,18 @@ if(isset($_GET['action'])) {
 			$sql.="sim_login=sim_login $where";
 			if($_POST['dev_disable_modify'] && $dev_disable==0) 
 				$db->query("update sim SET no_ring_remain=0,no_answer_remain=0,short_call_remain=0 $where and dev_disable=1 and ((short_call_disable=1 and short_call_limit>0 and short_call_remain>=short_call_limit) or (no_ring_disable=1 and no_ring_limit>0 and no_ring_remain>=no_ring_limit) or (no_answer_disable=1 and no_answer_limit>0 and no_answer_remain>=no_answer_limit))");
+			if($_POST['dev_disable_modify']){
+				$query=$db->query("select sim_name from sim $where and dev_disable!='$dev_disable'");
+				while($row=$db->fetch_array($query)) {
+					if($dev_disable==0) $db->query("insert into logs set sim_name='$row[sim_name]', log='enabled batch manually'");
+					else $db->query("insert into logs set sim_name='$row[sim_name]', log='disabled batch manually'");
+				}
+			};
 			$db->query($sql);
 
-
-
                         $query=$db->query("select sim.*,password from sim left join sim_bank on sim.bank_name=sim_bank.name $where");
 			while($row=$db->fetch_array($query)) {
+				if($_POST['month_reset_day_modify']) $db->query("insert into logs set sim_name='$row[sim_name]', log='change month limit'");
 				sim_info($row, $send);
 /*
 				if($row['imei_mode']==4) $row['imei_mode']=2;
@@ -314,6 +327,7 @@ if(isset($_GET['action'])) {
 
 		$query=$db->query("select sim.*,password from sim left join sim_bank on sim.bank_name=sim_bank.name $where");
 		while($row=$db->fetch_array($query)) {
+			$db->query("insert into logs set sim_name='$row[sim_name]', log='reset limit from web'");
 			sim_info($row, $send);
 /*
 			if($row['imei_mode']==4) $row['imei_mode']=2;
@@ -338,6 +352,7 @@ if(isset($_GET['action'])) {
 		
 		$query=$db->query("select sim_name from sim $where");
 		while($row=$db->fetch_array($query)) {
+			$db->query("insert into logs set sim_name='$row[sim_name]', log='reset period limit from web'");
 			$send[]=my_pack2(RESET_LIMIT, $row['sim_name']);
 		}
 		sendto_xchanged($send);
@@ -435,7 +450,7 @@ if(isset($_GET['action'])) {
 		if($action=="export"){
 			export_sim($where, $orderby);
 		}
-		$query=$db->query("SELECT sim.*,sim_team.sim_team_name,sim.line_name FROM sim left join sim_team on sim.sim_team_id=sim_team.sim_team_id left join device_line on device_line.line_name=sim.line_name $where $orderby LIMIT $start_limit,$perpage");
+		$query=$db->query("SELECT sim.*,sim_team.sim_team_name,sim.line_name,gsm_status FROM sim left join sim_team on sim.sim_team_id=sim_team.sim_team_id left join device_line on device_line.line_name=sim.line_name $where $orderby LIMIT $start_limit,$perpage");
 		while($row=$db->fetch_array($query)) {
 			if($row['sim_login'] == 0 || $row['sim_login'] == 12){
 				$row['alive']='<font color="#FF0000">OFFLINE</font>';
@@ -449,6 +464,13 @@ if(isset($_GET['action'])) {
 			elseif($row['sim_login'] == 14){
 				$row['alive']="BUSY";
 			}
+			if($row['gsm_status'] == 0 || $row['gsm_status'] == 30){
+				$row['gsm']='<font color="#FF0000">LOGOUT</font>';
+			}
+			else if($row['gsm_status'] == 31){
+				$row['gsm']='<font color="#00FF00">LOGIN</font>';
+			}
+
 			if($row['dev_disable'] == 0){
 				$row['disable'] = '<font color="#00FF00">Enable</font>';
 			}
