@@ -10,10 +10,16 @@ require_once("global.php");
 //$action="main";
 $action=$_REQUEST['action'];
 $sim_name=$_REQUEST['sim_name'];
+if($_REQUEST['chkAll0'] || $sim_name=="ALL") {
+	$sim_name="ALL";
+	$where="where 1";
+}else {
+	$where="where sim_name in ($sim_name)";
+}
+
 if($action=='modify'){
 
 	//print_r($_POST);
-	$sim_name=$_REQUEST['sim_name'];
 	$sql="update sim set period_limit='";
 	for($i=0;$i<=6;$i++)
 		for($j=1;$j<=9;$j++){
@@ -28,10 +34,11 @@ if($action=='modify'){
 			if($s && $e && ($l>=0 || $c>=0 || $sl>=0) && $s!=':' && $e!=':' )
 				$sql.="$i)$s-$e,$l,$c,$sl;";
 	}
-	$sql.="' where sim_name in ($sim_name)";
+	$sql.="' $where";
 	$db->query($sql);
-	$query=$db->query("select sim_name,period_limit from sim where sim_name in ($sim_name)");
+	$query=$db->query("select sim_name,period_limit from sim $where");
 	while($row=$db->fetch_array($query)) {
+		$db->query("insert into logs set sim_name='$row[sim_name]', log='change period limit'");
 		$send[]=my_pack($row, SIM_PERIOD);
 	}
 	sendto_xchanged($send);
@@ -56,6 +63,7 @@ else if($action=='modifymore'){
 
 	}
 	//echo "1".$sim_name;
+	if($_REQUEST['chkAll0']) $sim_name="ALL";
         echo "<script language='javascript'>";
         echo "window.location = '?sim_name=$sim_name'";
         echo "</script>";
