@@ -274,6 +274,11 @@ CREATE TABLE `sim` (
   `limit_sms` int(11) NOT NULL default '-1',
   `remain_sms` int(11) NOT NULL default '-1',
   `period_remain_sms` int(11) NOT NULL default '-1',
+  `month_remain_time` int(11) NOT NULL default '-1',
+  `month_limit_time` int(11) NOT NULL default '-1',
+  `month_reset_day` int(11) NOT NULL default '1',
+  `month_last_reset_time` timestamp NOT NULL default CURRENT_TIMESTAMP,
+  `simnum` VARCHAR( 32 ) NOT NULL,
   PRIMARY KEY  (`id`),
   KEY `sim_name` (`sim_name`),
   KEY `line_name` (`line_name`)
